# getcontinent

This library can help you find the continent of a given country on any given large dataset.

## Installation

Use the package manager [pip](https://pypi.org/project/getcontinent/) to install foobar.

```bash
pip install getcontinent
```

## Usage

```python
from getconti import getConti

# create an object of getConti
a = getConti()

# usage
india_continent = a.getContinents("India")

# it return continent name as string
china_continent = a.getContinents("china")
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)
